<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    {% block metas %}{% endblock %}
    <title>{{ title }}</title>
    {% block stylesheets %}{% endblock %}
</head>
<body>
{% block content %}{% endblock %}
{% block javascripts %}{% endblock %}
</body>
</html>